@@ -1,4 +1,4 @@
 # coding=utf-8
 from tf_geometric.datasets.ppi import PPIDataset
-from tf_geometric.datasets.cora import CoraDataset
-from tf_geometric.datasets.tu import TUDataset
\ No newline at end of file
+from tf_geometric.datasets.tu import TUDataset
+from tf_geometric.datasets.planetoid import PlanetoidDataset, CoraDataset, CiteseerDataset, PubmedDataset
\ No newline at end of file
