@@ -15,6 +15,8 @@ class GAT(MapReduceGNN):
                  query_activation=tf.nn.relu,
                  key_activation=tf.nn.relu,
                  drop_rate=0.0,
+                 kernel_regularizer=None,
+                 bias_regularizer=None,
                  *args, **kwargs):
         """
 
@@ -26,6 +28,8 @@ class GAT(MapReduceGNN):
         :param query_activation: Activation function for Q in attention.
         :param key_activation: Activation function for K in attention.
         :param drop_rate: Dropout rate.
+        :param kernel_regularizer: Regularizer function applied to the `kernel` weights matrix.
+        :param bias_regularizer: Regularizer function applied to the bias vector.
         """
         super().__init__(*args, **kwargs)
         self.units = units
@@ -47,19 +51,28 @@ class GAT(MapReduceGNN):
         self.use_bias = use_bias
         self.num_heads = num_heads
 
+        self.kernel_regularizer = kernel_regularizer
+        self.bias_regularizer = bias_regularizer
+
     def build(self, input_shapes):
         x_shape = input_shapes[0]
         num_features = x_shape[-1]
 
-        self.query_kernel = self.add_weight("query_kernel", shape=[num_features, self.attention_units], initializer="glorot_uniform")
-        self.query_bias = self.add_weight("query_bias", shape=[self.attention_units], initializer="zeros")
+        self.query_kernel = self.add_weight("query_kernel", shape=[num_features, self.attention_units],
+                                            initializer="glorot_uniform", regularizer=self.kernel_regularizer)
+        self.query_bias = self.add_weight("query_bias", shape=[self.attention_units],
+                                          initializer="zeros", regularizer=self.bias_regularizer)
 
-        self.key_kernel = self.add_weight("key_kernel", shape=[num_features, self.attention_units], initializer="glorot_uniform")
-        self.key_bias = self.add_weight("key_bias", shape=[self.attention_units], initializer="zeros")
+        self.key_kernel = self.add_weight("key_kernel", shape=[num_features, self.attention_units],
+                                          initializer="glorot_uniform", regularizer=self.kernel_regularizer)
+        self.key_bias = self.add_weight("key_bias", shape=[self.attention_units],
+                                        initializer="zeros", regularizer=self.bias_regularizer)
 
-        self.kernel = self.add_weight("kernel", shape=[num_features, self.units], initializer="glorot_uniform")
+        self.kernel = self.add_weight("kernel", shape=[num_features, self.units],
+                                      initializer="glorot_uniform", regularizer=self.kernel_regularizer)
         if self.use_bias:
-            self.bias = self.add_weight("bias", shape=[self.units], initializer="zeros")
+            self.bias = self.add_weight("bias", shape=[self.units],
+                                        initializer="zeros", regularizer=self.bias_regularizer)
 
     def call(self, inputs, training=None, mask=None):
         """
