@@ -13,12 +13,15 @@ class GCN(MapReduceGNN):
         x_shape = input_shapes[0]
         num_features = x_shape[-1]
 
-        self.kernel = self.add_weight("kernel", shape=[num_features, self.units], initializer="glorot_uniform")
+        self.kernel = self.add_weight("kernel", shape=[num_features, self.units],
+                                      initializer="glorot_uniform", regularizer=self.kernel_regularizer)
         if self.use_bias:
-            self.bias = self.add_weight("bias", shape=[self.units], initializer="zeros")
+            self.bias = self.add_weight("bias", shape=[self.units],
+                                        initializer="zeros", regularizer=self.bias_regularizer)
 
     def __init__(self, units, activation=None, use_bias=True,
-                 renorm=True, improved=False, *args, **kwargs):
+                 renorm=True, improved=False,
+                 kernel_regularizer=None, bias_regularizer=None, *args, **kwargs):
         """
 
         :param units: Positive integer, dimensionality of the output space.
@@ -26,6 +29,8 @@ class GCN(MapReduceGNN):
         :param use_bias: Boolean, whether the layer uses a bias vector.
         :param renorm: Whether use renormalization trick (https://arxiv.org/pdf/1609.02907.pdf).
         :param improved: Whether use improved GCN or not.
+        :param kernel_regularizer: Regularizer function applied to the `kernel` weights matrix.
+        :param bias_regularizer: Regularizer function applied to the bias vector.
         """
         super().__init__(*args, **kwargs)
         self.units = units
@@ -39,6 +44,9 @@ class GCN(MapReduceGNN):
         self.renorm = renorm
         self.improved = improved
 
+        self.kernel_regularizer = kernel_regularizer
+        self.bias_regularizer = bias_regularizer
+
     def call(self, inputs, cache=None, training=None, mask=None):
         """
 
@@ -54,4 +62,4 @@ class GCN(MapReduceGNN):
             edge_weight = None
 
         return gcn(x, edge_index, edge_weight, self.kernel, self.bias,
-                   activation=self.acvitation, renorm=self.renorm, improved=self.improved, cache=cache)
\ No newline at end of file
+                   activation=self.acvitation, renorm=self.renorm, improved=self.improved, cache=cache)
